package matcher

import (
	csm "git.loafle.net/commons/service_matcher-go"
	"git.loafle.net/commons/service_matcher-go/elasticsearch"
	"git.loafle.net/commons/service_matcher-go/ftp"
	"git.loafle.net/commons/service_matcher-go/http"
	"git.loafle.net/commons/service_matcher-go/ldap"
	"git.loafle.net/commons/service_matcher-go/lpd"
	"git.loafle.net/commons/service_matcher-go/mongodb"
	"git.loafle.net/commons/service_matcher-go/mysql"
	"git.loafle.net/commons/service_matcher-go/nbss"
	"git.loafle.net/commons/service_matcher-go/postgresql"
	"git.loafle.net/commons/service_matcher-go/redis"
	"git.loafle.net/commons/service_matcher-go/ssh"
	"git.loafle.net/commons/service_matcher-go/telnet"
)

var (
	AllMatchers []csm.Matcher

	TCPMatchers []csm.Matcher
	UDPMatchers []csm.UDPMatcher

	TCPPrePacketMatchers    []csm.Matcher
	TCPNotPrePacketMatchers []csm.Matcher
)

func init() {
	//TCP
	addTCPMatcher(ssh.NewMatcher())
	addTCPMatcher(mongodb.NewMatcher())
	addTCPMatcher(mysql.NewMatcher())
	addTCPMatcher(redis.NewMatcher())
	addTCPMatcher(postgresql.NewMatcher())
	addTCPMatcher(ftp.NewMatcher())
	addTCPMatcher(http.NewMatcher())
	addTCPMatcher(lpd.NewMatcher())
	addTCPMatcher(elasticsearch.NewMatcher())
	addTCPMatcher(telnet.NewMatcher())
	addTCPMatcher(nbss.NewMatcher())
	addTCPMatcher(ldap.NewMatcher())
	addTCPMatcher(mysql.NewMatcher())

	// UDP
}

func addTCPMatcher(m csm.Matcher) {
	AllMatchers = append(AllMatchers, m)
	TCPMatchers = append(TCPMatchers, m)
	if m.IsPrePacket() {
		TCPPrePacketMatchers = append(TCPPrePacketMatchers, m)
	} else {
		TCPNotPrePacketMatchers = append(TCPNotPrePacketMatchers, m)
	}
}

func addUDPMatcher(m csm.UDPMatcher) {
	AllMatchers = append(AllMatchers, m)
	UDPMatchers = append(UDPMatchers, m)
}

func GetTCPMatchers(isPrePacket bool) []csm.Matcher {
	if isPrePacket {
		return TCPPrePacketMatchers
	}

	return TCPNotPrePacketMatchers
}

func GetUDPMatchers() []csm.UDPMatcher {
	return UDPMatchers
}

func GetMatcherByKey(key string) csm.Matcher {
	for _, m := range AllMatchers {
		if m.Key() == key {
			return m
		}
	}
	return nil
}
